import _objectSpread from '@babel/runtime/helpers/esm/objectSpread2';
import _objectWithoutProperties from '@babel/runtime/helpers/esm/objectWithoutProperties';
import PropTypes from 'prop-types';
import { useBrand, getLabel, overrideReconciler } from '@westpac/core';
import { useContext, createContext, Children, cloneElement } from 'react';
import { jsx } from '@emotion/react/jsx-runtime';
import '@babel/runtime/helpers/defineProperty';
import { Body } from '@westpac/body';

var _excluded$g = ["state"];
var Wrapper = function Wrapper(_ref) {
  _ref.state;
    var rest = _objectWithoutProperties(_ref, _excluded$g);
  return jsx("div", _objectSpread({}, rest));
};

// ==============================
// Styles
// ==============================

var wrapperStyles = function wrapperStyles() {
  var _useBrand = useBrand();
    _useBrand.COLORS;
  return {
    label: getLabel('table-wrapper'),
    '@media screen and (max-width: 480px)': {
      width: '100%',
      marginBottom: '1.125rem',
      overflowY: 'hidden',
      overflowX: 'auto'
    }
  };
};

// ==============================
// Attributes
// ==============================

var wrapperAttributes = function wrapperAttributes() {
  return null;
};

// ==============================
// Exports
// ==============================

var defaultWrapper = {
  component: Wrapper,
  styles: wrapperStyles,
  attributes: wrapperAttributes
};

var pkg = {
	name: "@westpac/table",
	version: "2.3.0",
	description: "Styling for tables, including two visual styles and row/cell highlighting, used for displaying tabular data",
	homepage: "https://gel.westpacgroup.com.au/design-system",
	repository: "https://github.com/WestpacGEL/GEL/tree/master/components/table",
	license: "GPL-3.0+",
	author: "Westpac GEL Team <gel@westpac.com.au>",
	contributors: [
		{
			name: "Dominik Wilkowski",
			email: "Hi@Dominik-Wilkowski.com",
			url: "https://dominik-wilkowski.com"
		},
		{
			name: "Jonathan Stening",
			email: "info@jonathanstening.com",
			url: "http://jonathanstening.com"
		},
		{
			name: "Jeremy Ortiz",
			email: "jeremy@jeremyortiz.io",
			url: "https://www.jeremyortiz.io/"
		},
		{
			name: "Flore Laforge",
			email: "florelaforge@gmail.com",
			url: "http://florelaforge.com/"
		}
	],
	main: "dist/westpac-table.cjs.js",
	module: "dist/westpac-table.esm.js",
	scripts: {
		start: "PACKAGE_NAME=table NODE_ENV=development webpack server --config ../../helpers/example/start.webpack.config.js",
		test: "exit 0 # start-server-and-test start http://localhost:8080 test:all",
		"test:all": "yarn test:integration",
		"test:dev": "start-server-and-test start http://localhost:8080 test:test-dev",
		"test:integration": "cypress run",
		"test:test-dev": "cypress open"
	},
	dependencies: {
		"@babel/runtime": "^7.14.8",
		"@westpac/body": "^2.2.1",
		"@westpac/core": "^3.2.1",
		"prop-types": "^15.7.2"
	},
	devDependencies: {
		"@emotion/react": "^11.10.6",
		cypress: "^8.0.0",
		react: "^18.2.0",
		"start-server-and-test": "^1.12.6"
	},
	peerDependencies: {
		"@emotion/react": "^11.10.6",
		react: "^18.2.0"
	},
	blender: {
		recipe: "blender/recipe.js"
	},
	components: [
		{
			name: "Table",
			src: "Table.tsx"
		},
		{
			name: "Td",
			src: "Td.tsx"
		},
		{
			name: "Tr",
			src: "Tr.tsx"
		},
		{
			name: "Caption",
			src: "Caption.tsx"
		},
		{
			name: "Thead",
			src: "Thead.tsx"
		},
		{
			name: "Th",
			src: "Th.tsx"
		},
		{
			name: "Tbody",
			src: "Tbody.tsx"
		},
		{
			name: "Tfoot",
			src: "Tfoot.tsx"
		}
	]
};

var _excluded$f = ["highlighted", "highlightStart", "bordered", "children", "overrides"];
// ==============================
// Component
// ==============================

var Td$1 = function Td(_ref) {
  var _ref$highlighted = _ref.highlighted,
    highlighted = _ref$highlighted === void 0 ? false : _ref$highlighted,
    _ref$highlightStart = _ref.highlightStart,
    highlightStart = _ref$highlightStart === void 0 ? false : _ref$highlightStart,
    bordered = _ref.bordered,
    children = _ref.children,
    overrides = _ref.overrides,
    rest = _objectWithoutProperties(_ref, _excluded$f);
  var _useBrand = useBrand(),
    tokenOverrides = _useBrand.OVERRIDES[pkg.name],
    brandOverrides = _useBrand[pkg.name];
  var context = useTableContext();
  bordered = context && context.bordered || bordered;
  var defaultOverrides = {
    Td: defaultTd
  };
  var componentOverrides = overrides || context.state.overrides;
  var state = _objectSpread({
    highlighted: highlighted,
    highlightStart: highlightStart,
    bordered: bordered,
    context: context.state,
    overrides: componentOverrides
  }, rest);
  var _overrideReconciler = overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
    _overrideReconciler$T = _overrideReconciler.Td,
    Td = _overrideReconciler$T.component,
    tdStyles = _overrideReconciler$T.styles,
    tdAttributes = _overrideReconciler$T.attributes;
  return jsx(Td, _objectSpread(_objectSpread(_objectSpread({}, rest), {}, {
    state: state
  }, tdAttributes(state)), {}, {
    css: tdStyles(state),
    children: children
  }));
};
Td$1.propTypes = {
  // ----------------------------- Warning --------------------------------
  // | These PropTypes are generated from the TypeScript type definitions |
  // |     To update them edit TypeScript types and run "yarn prop-types"  |
  // ----------------------------------------------------------------------
  /**
   * Bordered mode
   */
  bordered: PropTypes.bool,
  /**
   * Children
   */
  children: PropTypes.node,
  /**
   * Whether or not the cell is highlighted
   */
  highlighted: PropTypes.bool,
  /**
   * Whether or not the start of the highlighted cells
   */
  highlightStart: PropTypes.bool,
  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Td: PropTypes.shape({
      attributes: PropTypes.func,
      component: PropTypes.elementType,
      styles: PropTypes.func
    })
  })
};

var _excluded$e = ["state"];
(Td$1 === null || Td$1 === void 0 ? void 0 : Td$1.defaultProps) || {};

// ==============================
// Component
// ==============================

var Td = function Td(_ref) {
  _ref.state;
    var rest = _objectWithoutProperties(_ref, _excluded$e);
  return jsx("td", _objectSpread({}, rest));
};

// ==============================
// Styles
// ==============================

var tdStyles = function tdStyles(_, _ref3) {
  var highlighted = _ref3.highlighted,
    highlightStart = _ref3.highlightStart,
    bordered = _ref3.bordered;
  var _useBrand = useBrand(),
    COLORS = _useBrand.COLORS,
    TYPE = _useBrand.TYPE;
  return {
    label: getLabel('table-td'),
    padding: '0.75rem',
    verticalAlign: 'top',
    border: bordered ? "1px solid ".concat(COLORS.border) : 'none',
    borderLeft: highlightStart && "6px solid ".concat(COLORS.primary),
    borderBottom: highlighted && "3px solid ".concat(COLORS.primary),
    //a11y: highlighted border must be noticeably thicker than non-highlighted

    // bold scope
    '&[scope=row]': _objectSpread({}, TYPE.bodyFont[700])
  };
};

// ==============================
// Attributes
// ==============================

var tdAttributes = function tdAttributes() {
  return null;
};
// ==============================
// Exports
// ==============================

var defaultTd = {
  component: Td,
  styles: tdStyles,
  attributes: tdAttributes
};

var _excluded$d = ["state"];
(Table === null || Table === void 0 ? void 0 : Table.defaultProps) || {};
// ==============================
// Component
// ==============================

var TFoot = function TFoot(_ref) {
  _ref.state;
    var rest = _objectWithoutProperties(_ref, _excluded$d);
  return jsx("tfoot", _objectSpread({}, rest));
};

// ==============================
// Styles
// ==============================

var tfootStyles = function tfootStyles(_, _ref2) {
  var bordered = _ref2.bordered;
  var _useBrand = useBrand(),
    COLORS = _useBrand.COLORS;
  return {
    label: getLabel('table-tfoot'),
    color: COLORS.muted,
    'th, tr, td': {
      borderBottom: !bordered ? "0" : "1px solid ".concat(COLORS.border)
    }
  };
};

// ==============================
// Attributes
// ==============================

var tfootAttributes = function tfootAttributes() {
  return null;
};

// ==============================
// Exports
// ==============================

var defaultTfoot = {
  component: TFoot,
  styles: tfootStyles,
  attributes: tfootAttributes
};

var _excluded$c = ["state"];
(Table === null || Table === void 0 ? void 0 : Table.defaultProps) || {};

// ==============================
// Component
// ==============================

var Th$1 = function Th(_ref) {
  _ref.state;
    var rest = _objectWithoutProperties(_ref, _excluded$c);
  return jsx("th", _objectSpread({}, rest));
};

// ==============================
// Styles
// ==============================

var thStyles = function thStyles(_, _ref2) {
  var bordered = _ref2.bordered;
  var _useBrand = useBrand(),
    COLORS = _useBrand.COLORS;
  return {
    label: getLabel('table-th'),
    padding: '0.75rem',
    verticalAlign: 'top',
    border: "1px solid ".concat(COLORS.border),
    borderLeft: !bordered ? 0 : "1px solid ".concat(COLORS.border),
    borderRight: !bordered ? 0 : "1px solid ".concat(COLORS.border),
    textAlign: 'left'
  };
};

// ==============================
// Attributes
// ==============================

var thAttributes = function thAttributes() {
  return null;
};

// ==============================
// Exports
// ==============================

var defaultTh = {
  component: Th$1,
  styles: thStyles,
  attributes: thAttributes
};

var _excluded$b = ["state"];
(Table === null || Table === void 0 ? void 0 : Table.defaultProps) || {};
// ==============================
// Component
// ==============================

var Thead$1 = function Thead(_ref) {
  _ref.state;
    var rest = _objectWithoutProperties(_ref, _excluded$b);
  return jsx("thead", _objectSpread({}, rest));
};

// ==============================
// Styles
// ==============================

var theadStyles = function theadStyles(_, _ref2) {
  var bordered = _ref2.bordered;
  var _useBrand = useBrand(),
    COLORS = _useBrand.COLORS,
    TYPE = _useBrand.TYPE;
  return {
    label: getLabel('table-thead'),
    'th, td': {
      borderTop: !bordered ? 0 : "1px solid ".concat(COLORS.border)
    },
    // `th` cells in the `thead`
    th: _objectSpread({
      verticalAlign: 'bottom',
      borderBottom: "".concat(bordered ? '2px' : '3px', " solid ").concat(COLORS.hero),
      color: COLORS.text
    }, TYPE.bodyFont[700])
  };
};

// ==============================
// Attributes
// ==============================

var theadAttributes = function theadAttributes() {
  return null;
};

// ==============================
// Exports
// ==============================

var defaultThead = {
  component: Thead$1,
  styles: theadStyles,
  attributes: theadAttributes
};

var _excluded$a = ["state"];
(Table === null || Table === void 0 ? void 0 : Table.defaultProps) || {};
var Table$1 = function Table(_ref) {
  _ref.state;
    var rest = _objectWithoutProperties(_ref, _excluded$a);
  return jsx(Body, _objectSpread({
    tag: "table"
  }, rest));
};

// ==============================
// Styles
// ==============================

var tableStyles = function tableStyles(_, _ref3) {
  var striped = _ref3.striped;
  var _useBrand = useBrand(),
    COLORS = _useBrand.COLORS,
    SPACING = _useBrand.SPACING;
  return {
    label: getLabel('table'),
    width: '100%',
    maxWidth: '100%',
    marginBottom: SPACING(4),
    backgroundColor: COLORS.white,
    borderCollapse: 'collapse',
    // Odd row
    'tbody > tr:nth-of-type(even)': {
      backgroundColor: striped && COLORS.light,
      ':hover': {
        // for blender
        backgroundColor: striped && COLORS.light
      }
    },
    // for blender
    'tbody > tr:nth-of-type(odd):hover': {
      backgroundColor: striped && 'transparent'
    },
    'tbody > tr': {
      transition: !striped ? 'background 0.2s ease' : 'none',
      ':hover': {
        backgroundColor: !striped && COLORS.background
      }
    },
    // Adjacent `tbody` elements
    'tbody + tbody': {
      borderTop: "2px solid ".concat(COLORS.hero)
    }
  };
};

// ==============================
// Attributes
// ==============================

var tableAttributes = function tableAttributes() {
  return null;
};

// ==============================
// Exports
// ==============================

var defaultTable = {
  component: Table$1,
  styles: tableStyles,
  attributes: tableAttributes
};

var _excluded$9 = ["striped", "bordered", "children", "overrides"];
var TableContext = /*#__PURE__*/createContext(null);
var useTableContext = function useTableContext() {
  var context = useContext(TableContext);
  if (!context) {
    throw new Error('Table sub-components should be wrapped in a <Table>.');
  }
  return context;
};
// ==============================
// Component
// ==============================

var Table = function Table(_ref) {
  var _ref$striped = _ref.striped,
    striped = _ref$striped === void 0 ? false : _ref$striped,
    _ref$bordered = _ref.bordered,
    bordered = _ref$bordered === void 0 ? false : _ref$bordered,
    children = _ref.children,
    componentOverrides = _ref.overrides,
    rest = _objectWithoutProperties(_ref, _excluded$9);
  var context = useContext(TableContext);
  bordered = context && context.bordered || bordered;
  var _useBrand = useBrand(),
    tokenOverrides = _useBrand.OVERRIDES[pkg.name],
    brandOverrides = _useBrand[pkg.name];
  var defaultOverrides = {
    Wrapper: defaultWrapper,
    Table: defaultTable
  };
  var state = _objectSpread({
    striped: striped,
    bordered: bordered,
    overrides: componentOverrides
  }, rest);
  var _overrideReconciler = overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
    _overrideReconciler$W = _overrideReconciler.Wrapper,
    Wrapper = _overrideReconciler$W.component,
    wrapperStyles = _overrideReconciler$W.styles,
    wrapperAttributes = _overrideReconciler$W.attributes,
    _overrideReconciler$T = _overrideReconciler.Table,
    Table = _overrideReconciler$T.component,
    tableStyles = _overrideReconciler$T.styles,
    tableAttributes = _overrideReconciler$T.attributes;
  return jsx(TableContext.Provider, {
    value: {
      striped: striped,
      bordered: bordered,
      state: state
    },
    children: jsx(Wrapper, _objectSpread(_objectSpread({
      state: state
    }, wrapperAttributes(state)), {}, {
      css: wrapperStyles(state),
      children: jsx(Table, _objectSpread(_objectSpread(_objectSpread({}, rest), {}, {
        state: state
      }, tableAttributes(state)), {}, {
        css: tableStyles(state),
        children: children
      }))
    }))
  });
};
Table.propTypes = {
  // ----------------------------- Warning --------------------------------
  // | These PropTypes are generated from the TypeScript type definitions |
  // |     To update them edit TypeScript types and run "yarn prop-types"  |
  // ----------------------------------------------------------------------
  /**
   * Bordered mode
   */
  bordered: PropTypes.bool,
  /**
   * Children
   */
  children: PropTypes.node,
  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Caption: PropTypes.shape({
      attributes: PropTypes.func,
      component: PropTypes.elementType,
      styles: PropTypes.func
    }),
    Table: PropTypes.shape({
      attributes: PropTypes.func,
      component: PropTypes.elementType,
      styles: PropTypes.func
    }),
    Tbody: PropTypes.shape({
      attributes: PropTypes.func,
      component: PropTypes.elementType,
      styles: PropTypes.func
    }),
    Td: PropTypes.shape({
      attributes: PropTypes.func,
      component: PropTypes.elementType,
      styles: PropTypes.func
    }),
    Tfoot: PropTypes.shape({
      attributes: PropTypes.func,
      component: PropTypes.elementType,
      styles: PropTypes.func
    }),
    Th: PropTypes.shape({
      attributes: PropTypes.func,
      component: PropTypes.elementType,
      styles: PropTypes.func
    }),
    Thead: PropTypes.shape({
      attributes: PropTypes.func,
      component: PropTypes.elementType,
      styles: PropTypes.func
    }),
    Tr: PropTypes.shape({
      attributes: PropTypes.func,
      component: PropTypes.elementType,
      styles: PropTypes.func
    })
  }),
  /**
   * Striped mode
   */
  striped: PropTypes.bool
};

var _excluded$8 = ["state"];
var Caption$1 = function Caption(_ref) {
  _ref.state;
    var rest = _objectWithoutProperties(_ref, _excluded$8);
  return jsx("caption", _objectSpread({}, rest));
};

// ==============================
// Styles
// ==============================

var captionStyles = function captionStyles() {
  var _useBrand = useBrand(),
    TYPE = _useBrand.TYPE;
  return _objectSpread({
    label: getLabel('table-caption'),
    fontSize: '1.125rem',
    textAlign: 'left',
    marginBottom: '0.75rem'
  }, TYPE.bodyFont[300]);
};

// ==============================
// Attributes
// ==============================

var captionAttributes = function captionAttributes() {
  return null;
};

// ==============================
// Exports
// ==============================

var defaultCaption = {
  component: Caption$1,
  styles: captionStyles,
  attributes: captionAttributes
};

var _excluded$7 = ["children", "overrides"];
// ==============================
// Component
// ==============================

var Caption = function Caption(_ref) {
  var children = _ref.children,
    overrides = _ref.overrides,
    rest = _objectWithoutProperties(_ref, _excluded$7);
  var _useBrand = useBrand(),
    tokenOverrides = _useBrand.OVERRIDES[pkg.name],
    brandOverrides = _useBrand[pkg.name];
  var context = useTableContext();
  var defaultOverrides = {
    Caption: defaultCaption
  };
  var componentOverrides = overrides || context.state.overrides;
  var state = _objectSpread({
    context: context.state,
    overrides: componentOverrides
  }, rest);
  var _overrideReconciler = overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
    _overrideReconciler$C = _overrideReconciler.Caption,
    Caption = _overrideReconciler$C.component,
    CaptionStyles = _overrideReconciler$C.styles,
    CaptionAttributes = _overrideReconciler$C.attributes;
  return jsx(Caption, _objectSpread(_objectSpread(_objectSpread({}, rest), {}, {
    state: state
  }, CaptionAttributes(state)), {}, {
    css: CaptionStyles(state),
    children: children
  }));
};
Caption.propTypes = {
  // ----------------------------- Warning --------------------------------
  // | These PropTypes are generated from the TypeScript type definitions |
  // |     To update them edit TypeScript types and run "yarn prop-types"  |
  // ----------------------------------------------------------------------
  /**
   * Children
   */
  children: PropTypes.node,
  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Caption: PropTypes.shape({
      attributes: PropTypes.func,
      component: PropTypes.elementType,
      styles: PropTypes.func
    })
  })
};

var _excluded$6 = ["bordered", "children", "overrides"];
// ==============================
// Component
// ==============================

var Thead = function Thead(_ref) {
  var bordered = _ref.bordered,
    children = _ref.children,
    overrides = _ref.overrides,
    rest = _objectWithoutProperties(_ref, _excluded$6);
  var _useBrand = useBrand(),
    tokenOverrides = _useBrand.OVERRIDES[pkg.name],
    brandOverrides = _useBrand[pkg.name];
  var context = useTableContext();
  bordered = context && context.bordered || bordered;
  var defaultOverrides = {
    Thead: defaultThead
  };
  var componentOverrides = overrides || context.state.overrides;
  var state = _objectSpread({
    bordered: bordered,
    context: context.state,
    overrides: componentOverrides
  }, rest);
  var _overrideReconciler = overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
    _overrideReconciler$T = _overrideReconciler.Thead,
    Thead = _overrideReconciler$T.component,
    theadStyles = _overrideReconciler$T.styles,
    theadAttributes = _overrideReconciler$T.attributes;
  return jsx(Thead, _objectSpread(_objectSpread(_objectSpread({}, rest), {}, {
    state: state
  }, theadAttributes(state)), {}, {
    css: theadStyles(state),
    children: children
  }));
};
Thead.propTypes = {
  // ----------------------------- Warning --------------------------------
  // | These PropTypes are generated from the TypeScript type definitions |
  // |     To update them edit TypeScript types and run "yarn prop-types"  |
  // ----------------------------------------------------------------------
  /**
   * Whether or not there should border styling
   */
  bordered: PropTypes.bool,
  /**
   * Children
   */
  children: PropTypes.node,
  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Thead: PropTypes.shape({
      attributes: PropTypes.func,
      component: PropTypes.elementType,
      styles: PropTypes.func
    })
  })
};

var _excluded$5 = ["state"];
(Tr === null || Tr === void 0 ? void 0 : Tr.defaultProps) || {};

// ==============================
// Component
// ==============================

var Tr$1 = function Tr(_ref) {
  _ref.state;
    var rest = _objectWithoutProperties(_ref, _excluded$5);
  return jsx("tr", _objectSpread({}, rest));
};

// ==============================
// Styles
// ==============================

var trStyles = function trStyles(_, _ref3) {
  var highlighted = _ref3.highlighted;
  var _useBrand = useBrand(),
    COLORS = _useBrand.COLORS;
  return {
    label: getLabel('table-tr'),
    borderLeft: typeof highlighted === 'boolean' && highlighted ? "6px solid ".concat(COLORS.primary) : 0,
    borderBottom: typeof highlighted === 'boolean' && highlighted ? "3px solid ".concat(COLORS.primary) : "1px solid ".concat(COLORS.border) //a11y: highlighted border must be noticeably thicker than non-highlighted
  };
};

// ==============================
// Attributes
// ==============================

var trAttributes = function trAttributes() {
  return null;
};
// ==============================
// Exports
// ==============================

var defaultTr = {
  component: Tr$1,
  styles: trStyles,
  attributes: trAttributes
};

var _excluded$4 = ["striped", "highlighted", "children", "overrides"];
var generateHighlightMap = function generateHighlightMap(highlighted, tdCount) {
  var map = Array(tdCount).fill(false);
  highlighted.forEach(function (highlight) {
    if (typeof highlight === 'number') {
      map[highlight] = true;
    } else if (Array.isArray(highlight)) {
      map.fill(true, highlight[0], highlight[1] + 1);
    }
  });
  return map;
};
// ==============================
// Component
// ==============================

var Tr = function Tr(_ref) {
  var striped = _ref.striped,
    _ref$highlighted = _ref.highlighted,
    highlighted = _ref$highlighted === void 0 ? false : _ref$highlighted,
    children = _ref.children,
    overrides = _ref.overrides,
    rest = _objectWithoutProperties(_ref, _excluded$4);
  var _useBrand = useBrand(),
    tokenOverrides = _useBrand.OVERRIDES[pkg.name],
    brandOverrides = _useBrand[pkg.name];
  var context = useTableContext();
  striped = context && context.striped || striped;
  var defaultOverrides = {
    Tr: defaultTr
  };
  var componentOverrides = overrides || context.state.overrides;
  var state = _objectSpread({
    striped: striped,
    highlighted: highlighted,
    context: context.state,
    overrides: componentOverrides
  }, rest);
  var _overrideReconciler = overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
    _overrideReconciler$T = _overrideReconciler.Tr,
    Tr = _overrideReconciler$T.component,
    trStyles = _overrideReconciler$T.styles,
    trAttributes = _overrideReconciler$T.attributes;
  var highlightedChildren;
  if (Array.isArray(highlighted)) {
    var highlightMap = generateHighlightMap(highlighted, Children.count(children));
    highlightedChildren = Children.map(children, function (child, index) {
      if (highlightMap[index] === true) {
        if (index === 0 || highlightMap[index - 1] === false) {
          return /*#__PURE__*/cloneElement(child, {
            highlightStart: true,
            highlighted: true
          });
        } else {
          return /*#__PURE__*/cloneElement(child, {
            highlighted: true
          });
        }
      } else {
        return child;
      }
    });
  }
  return jsx(Tr, _objectSpread(_objectSpread(_objectSpread({}, rest), {}, {
    state: state
  }, trAttributes(state)), {}, {
    css: trStyles(state),
    children: highlightedChildren || children
  }));
};
Tr.propTypes = {
  // ----------------------------- Warning --------------------------------
  // | These PropTypes are generated from the TypeScript type definitions |
  // |     To update them edit TypeScript types and run "yarn prop-types"  |
  // ----------------------------------------------------------------------
  /**
   * Children
   */
  children: PropTypes.node,
  /**
   * Highlighted mode
   */
  highlighted: PropTypes.oneOfType([PropTypes.array, PropTypes.bool]),
  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Tr: PropTypes.shape({
      attributes: PropTypes.func,
      component: PropTypes.elementType,
      styles: PropTypes.func
    })
  }),
  /**
   * striped
   */
  striped: PropTypes.any
};

var _excluded$3 = ["bordered", "children", "overrides"];
// ==============================
// Component
// ==============================

var Th = function Th(_ref) {
  var bordered = _ref.bordered,
    children = _ref.children,
    overrides = _ref.overrides,
    rest = _objectWithoutProperties(_ref, _excluded$3);
  var _useBrand = useBrand(),
    tokenOverrides = _useBrand.OVERRIDES[pkg.name],
    brandOverrides = _useBrand[pkg.name];
  var context = useTableContext();
  bordered = context && context.bordered || bordered;
  var defaultOverrides = {
    Th: defaultTh
  };
  var componentOverrides = overrides || context.state.overrides;
  var state = _objectSpread({
    bordered: bordered,
    context: context.state,
    overrides: componentOverrides
  }, rest);
  var _overrideReconciler = overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
    _overrideReconciler$T = _overrideReconciler.Th,
    Th = _overrideReconciler$T.component,
    thStyles = _overrideReconciler$T.styles,
    thAttributes = _overrideReconciler$T.attributes;
  return jsx(Th, _objectSpread(_objectSpread(_objectSpread({}, rest), {}, {
    state: state
  }, thAttributes(state)), {}, {
    css: thStyles(state),
    children: children
  }));
};
Th.propTypes = {
  // ----------------------------- Warning --------------------------------
  // | These PropTypes are generated from the TypeScript type definitions |
  // |     To update them edit TypeScript types and run "yarn prop-types"  |
  // ----------------------------------------------------------------------
  /**
   * Whether or not there should border styling
   */
  bordered: PropTypes.bool,
  /**
   * Children
   */
  children: PropTypes.node,
  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Th: PropTypes.shape({
      attributes: PropTypes.func,
      component: PropTypes.elementType,
      styles: PropTypes.func
    })
  })
};

var _excluded$2 = ["state"];
var Tbody$1 = function Tbody(_ref) {
  _ref.state;
    var rest = _objectWithoutProperties(_ref, _excluded$2);
  return jsx("tbody", _objectSpread({}, rest));
};

// ==============================
// Styles
// ==============================

var tbodyStyles = function tbodyStyles() {
  return {
    label: getLabel('table-tbody')
  };
};

// ==============================
// Attributes
// ==============================

var tbodyAttributes = function tbodyAttributes() {
  return null;
};

// ==============================
// Exports
// ==============================

var defaultTBody = {
  component: Tbody$1,
  styles: tbodyStyles,
  attributes: tbodyAttributes
};

var _excluded$1 = ["children", "overrides"];
// ==============================
// Component
// ==============================

var Tbody = function Tbody(_ref) {
  var children = _ref.children,
    overrides = _ref.overrides,
    rest = _objectWithoutProperties(_ref, _excluded$1);
  var _useBrand = useBrand(),
    tokenOverrides = _useBrand.OVERRIDES[pkg.name],
    brandOverrides = _useBrand[pkg.name];
  var context = useTableContext();
  var defaultOverrides = {
    Tbody: defaultTBody
  };
  var componentOverrides = overrides || context.state.overrides;
  var state = _objectSpread({
    context: context.state,
    overrides: componentOverrides
  }, rest);
  var _overrideReconciler = overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
    _overrideReconciler$T = _overrideReconciler.Tbody,
    Tbody = _overrideReconciler$T.component,
    tbodyStyles = _overrideReconciler$T.styles,
    tbodyAttributes = _overrideReconciler$T.attributes;
  return jsx(Tbody, _objectSpread(_objectSpread(_objectSpread({}, rest), {}, {
    state: state
  }, tbodyAttributes(state)), {}, {
    css: tbodyStyles(state),
    children: children
  }));
};
Tbody.propTypes = {
  // ----------------------------- Warning --------------------------------
  // | These PropTypes are generated from the TypeScript type definitions |
  // |     To update them edit TypeScript types and run "yarn prop-types"  |
  // ----------------------------------------------------------------------
  /**
   * Children
   */
  children: PropTypes.node,
  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Tbody: PropTypes.shape({
      attributes: PropTypes.func,
      component: PropTypes.elementType,
      styles: PropTypes.func
    })
  })
};

var _excluded = ["bordered", "children", "overrides"];
// ==============================
// Component
// ==============================

var Tfoot = function Tfoot(_ref) {
  var bordered = _ref.bordered,
    children = _ref.children,
    overrides = _ref.overrides,
    rest = _objectWithoutProperties(_ref, _excluded);
  var _useBrand = useBrand(),
    tokenOverrides = _useBrand.OVERRIDES[pkg.name],
    brandOverrides = _useBrand[pkg.name];
  var context = useTableContext();
  bordered = context && context.bordered || bordered;
  var defaultOverrides = {
    Tfoot: defaultTfoot
  };
  var componentOverrides = overrides || context.state.overrides;
  var state = _objectSpread({
    bordered: bordered,
    context: context.state,
    overrides: componentOverrides
  }, rest);
  var _overrideReconciler = overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
    _overrideReconciler$T = _overrideReconciler.Tfoot,
    Tfoot = _overrideReconciler$T.component,
    tfootStyles = _overrideReconciler$T.styles,
    tfootAttributes = _overrideReconciler$T.attributes;
  return jsx(Tfoot, _objectSpread(_objectSpread(_objectSpread({}, rest), {}, {
    state: state
  }, tfootAttributes(state)), {}, {
    css: tfootStyles(state),
    children: children
  }));
};
Tfoot.propTypes = {
  // ----------------------------- Warning --------------------------------
  // | These PropTypes are generated from the TypeScript type definitions |
  // |     To update them edit TypeScript types and run "yarn prop-types"  |
  // ----------------------------------------------------------------------
  /**
   * Whether or not there should border styling
   */
  bordered: PropTypes.bool,
  /**
   * Children
   */
  children: PropTypes.node,
  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Tfoot: PropTypes.shape({
      attributes: PropTypes.func,
      component: PropTypes.elementType,
      styles: PropTypes.func
    })
  })
};

export { Caption, Table, Tbody, Td$1 as Td, Tfoot, Th, Thead, Tr };
